.. :changelog:


Changelog
---------

v0.3.1 (2013-04-20)
^^^^^^^^^^^^^^^^^^^

- Fix issue with serial queue names
- admin fixes

v0.3 (2013-04-10)
^^^^^^^^^^^^^^^^^

- Added south migrations
- Added a simple workflow class Flow
- Added weekdays option for scheduled_call/enqueued_call

v0.2 (2013-04-6)
^^^^^^^^^^^^^^^^^

- Implement scheduled tasks
- Implement a serial queue


v0.1 (2013-03-29)
^^^^^^^^^^^^^^^^^

- Initial public release
